@@ -109,8 +109,8 @@
 
 /* Libraries */
 /* #undef HAVE_LIBWRAP */
-/* #undef HAVE_SYSTEMD */
-/* #undef HAVE_SYSTEMD_SD_LISTEN_FDS_WITH_NAMES */
+#define HAVE_SYSTEMD 1
+#define HAVE_SYSTEMD_SD_LISTEN_FDS_WITH_NAMES 1
 
 /* Does "struct timespec" have a "sec" and "nsec" field? */
 /* #undef HAVE_TIMESPEC_TS_SEC */
@@ -518,17 +518,17 @@ this is the case with Microsoft Windows VirtualFree(MEM_DECOMMIT) */
 /* #undef SO_EXT */
 
 #define MYSQL_VERSION_MAJOR 12
-#define MYSQL_VERSION_MINOR 0
+#define MYSQL_VERSION_MINOR 2
 #define MYSQL_VERSION_PATCH 2
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 12.0.2"
+#define PACKAGE_STRING "MySQL Server 12.2.2"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "12.0.2"
-#define VERSION "12.0.2"
+#define PACKAGE_VERSION "12.2.2"
+#define VERSION "12.2.2"
 #define PROTOCOL_VERSION 10
 #define PCRE2_CODE_UNIT_WIDTH 8
 
